summaryrefslogtreecommitdiffstats
path: root/make_slackware_live.sh
diff options
context:
space:
mode:
author Eric Hameleers <alien@slackware.com>2017-01-23 16:56:17 +0100
committer Eric Hameleers <alien@slackware.com>2017-01-23 16:56:17 +0100
commitad247494598972b0727253f9812e117c18fb4e4b (patch)
tree0d135b135226e199590261457d45247d880387e3 /make_slackware_live.sh
parent734eb5ec860bea83c480d34437b0e3e729b66a5d (diff)
parentc81ada6132a864362044641705efb4a8986bf26e (diff)
downloadliveslak-ad247494598972b0727253f9812e117c18fb4e4b.tar.gz
liveslak-ad247494598972b0727253f9812e117c18fb4e4b.tar.xz
Merge branch 'dlack'
New supported LIVEDE value: DLACK This merge adds Dlackware as a DE choice when generating the ISO. Dlackware is Slackware with PAM, systemd and Gnome3 (and without KDE4). I think this is an interesting experiment. Know your enemy ;-) Thanks to bartgymnast of the Dlackware team who provided the patches.
Diffstat (limited to 'make_slackware_live.sh')
-rwxr-xr-xmake_slackware_live.sh39
1 files changed, 36 insertions, 3 deletions
diff --git a/make_slackware_live.sh b/make_slackware_live.sh
index 746bbbc..a5b4cfb 100755
--- a/make_slackware_live.sh
+++ b/make_slackware_live.sh
@@ -94,7 +94,7 @@ DISTRO=${DISTRO:-"slackware"}
LIVE_HOSTNAME=${LIVE_HOSTNAME:-"darkstar"}
# What type of Live image?
# Choices are: SLACKWARE, XFCE, KDE4, PLASMA5, MATE, CINNAMON
LIVEDE=${LIVEDE:-"SLACKWARE"}
# What runlevel to use if adding a DE like: XFCE, KDE4, PLASMA5 etc...
@@ -182,6 +182,10 @@ SEQ_MSB="tagfile:a,ap,d,e,f,k,l,n,t,tcl,x,xap,xfce,y pkglist:slackextra,mate loc
# - each will become a squashfs module:
SEQ_CIN="tagfile:a,ap,d,e,f,k,l,n,t,tcl,x,xap,xfce,y pkglist:slackextra,cinnamon local:slackpkg+"
+# Slackware package series with Gnome3/systemd instead of KDE4 (full install):
+# - each will become a squashfs module:
+SEQ_DLACK="tagfile:a,ap,d,e,f,k,l,n,t,tcl,x,xap pkglist:slackextra,systemd,dlackware"
+
# List of kernel modules required for a live medium to boot properly;
# Lots of HID modules added to support keyboard input for LUKS password entry:
KMODS=${KMODS:-"squashfs:overlay:loop:xhci-pci:ohci-pci:ehci-pci:xhci-hcd:uhci-hcd:ehci-hcd:usb-storage:hid:usbhid:i2c-hid:hid-generic:hid-cherry:hid-logitech:hid-logitech-dj:hid-logitech-hidpp:hid-lenovo:hid-microsoft:hid_multitouch:jbd:mbcache:ext3:ext4:isofs:fat:nls_cp437:nls_iso8859-1:msdos:vfat:ntfs"}
@@ -758,8 +762,8 @@ do
echo " -h This help."
echo " -a arch Machine architecture (default: ${SL_ARCH})."
echo " Use i586 for a 32bit ISO, x86_64 for 64bit."
- echo " -d desktoptype SLACKWARE (full Slack), KDE4 (basic KDE4),"
- echo " XFCE (basic XFCE), PLASMA5, MATE, CINNAMON."
+ echo " -d desktoptype SLACKWARE (full Slack), KDE4 basic,"
+ echo " XFCE basic, PLASMA5, MATE, CINNAMON, DLACK."
echo " -e Use ISO boot-load-size of 32 for computers."
echo " where the ISO won't boot otherwise."
echo " -f Forced re-generation of all squashfs modules,"
@@ -960,6 +964,7 @@ case "$LIVEDE" in
PLASMA5) MSEQ="${SEQ_PLASMA5}" ;;
MATE) MSEQ="${SEQ_MSB}" ;;
CINNAMON) MSEQ="${SEQ_CIN}" ;;
+ DLACK) MSEQ="${SEQ_DLACK}" ;;
*) if [ -n "${SEQ_CUSTOM}" ]; then
# Custom distribution with a predefined package list:
MSEQ="${SEQ_CUSTOM}"
@@ -1124,6 +1129,9 @@ if grep -q "^ *export LANG=" ${LIVE_ROOTDIR}/etc/profile.d/lang.sh ; then
else
echo "export LANG=en_US.UTF-8" >> ${LIVE_ROOTDIR}/etc/profile.d/lang.sh
fi
+# Does not hurt to also add systemd compatible configuration:
+echo "LANG=en_US.UTF-8" > ${LIVE_ROOTDIR}/etc/locale.conf
+echo "KEYMAP=us" > ${LIVE_ROOTDIR}/etc/vconsole.conf
# Set timezone to UTC:
cp -a ${LIVE_ROOTDIR}/usr/share/zoneinfo/UTC ${LIVE_ROOTDIR}/etc/localtime
@@ -1620,6 +1628,29 @@ EOGL
fi # End LIVEDE = PLASMA5
+if [ "$LIVEDE" = "DLACK" ]; then
+
+ # -------------------------------------------------------------------------- #
+ echo "-- Configuring DLACK."
+ # -------------------------------------------------------------------------- #
+
+ # Make sure we start in graphical mode with gdm enabled.
+ ln -sf /lib/systemd/system/graphical.target ${LIVE_ROOTDIR}/etc/systemd/system/default.target
+ ln -sf /lib/systemd/system/gdm.service ${LIVE_ROOTDIR}/etc/systemd/system/display-manager.service
+
+ # Do not show the blueman applet, Gnome3 has its own BlueTooth widget:
+ echo "NotShowIn=GNOME;" >> ${LIVE_ROOTDIR}/etc/xdg/autostart/blueman.desktop
+
+ # Do not start gnome-initial-setup:
+ mkdir -p ${LIVE_ROOTDIR}/home/${LIVEUID}/.config
+ touch ${LIVE_ROOTDIR}/home/${LIVEUID}/.config/gnome-initial-setup-done
+
+ # Do not let systemd re-generate dynamic linker cache on boot:
+ echo "File created by ${MARKER}. See systemd-update-done.service(8)." \
+ |tee ${LIVE_ROOTDIR}/etc/.updated >${LIVE_ROOTDIR}/var/.updated
+
+fi # End LIVEDE = DLACK
+
# You can define the function 'custom_config()' by uncommenting it in
# the configuration file 'make_slackware_live.conf'.
if type custom_config 1>/dev/null 2>/dev/null ; then
@@ -1662,6 +1693,8 @@ elif [ "$LIVEDE" = "MATE" ]; then
ln -sf xinitrc.mate-session ${LIVE_ROOTDIR}/etc/X11/xinit/xinitrc
elif [ "$LIVEDE" = "CINNAMON" ]; then
ln -sf xinitrc.cinnamon-session ${LIVE_ROOTDIR}/etc/X11/xinit/xinitrc
+elif [ "$LIVEDE" = "DLACK" ]; then
+ ln -sf xinitrc.gnome ${LIVE_ROOTDIR}/etc/X11/xinit/xinitrc
elif [ -f ${LIVE_ROOTDIR}/etc/X11/xinit/xinitrc.xfce ]; then
ln -sf xinitrc.xfce ${LIVE_ROOTDIR}/etc/X11/xinit/xinitrc
fi
@@ -94,7 +94,7 @@ DISTRO=${DISTRO:-"slackware"}
LIVE_HOSTNAME=${LIVE_HOSTNAME:-"darkstar"}
# What type of Live image?
-# Choices are: SLACKWARE, XFCE, KDE4, PLASMA5, MATE, CINNAMON
+# Choices are: SLACKWARE, XFCE, KDE4, PLASMA5, MATE, CINNAMON, DLACK
LIVEDE=${LIVEDE:-"SLACKWARE"}
# What runlevel to use if adding a DE like: XFCE, KDE4, PLASMA5 etc...